@@ -53,6 +53,7 @@ options_ident = set_default_option(options_ident,'prior_range',0);
 options_ident = set_default_option(options_ident,'periods',300);
 options_ident = set_default_option(options_ident,'replic',100);
 options_ident = set_default_option(options_ident,'advanced',0);
+options_ident = set_default_option(options_ident,'lik_init',1);
 
 if nargin==2,
     options_ident.prior_mc=size(pdraws0,1);
@@ -156,7 +157,7 @@ if iload <=0,
     if SampleSize==1,
         BurninSampleSize=0;
     else
-        BurninSampleSize=50;
+        BurninSampleSize=min(SampleSize,50);
     end
     loop_indx = 0;
     file_index = 0;
@@ -350,6 +351,7 @@ if iload <=0,
                     else
                         normaliz1 = ones(1,nparam);
                     end
+                    replic=max(replic,3*length(indJJ));
                     cmm = simulated_moment_uncertainty(indJJ, periods, replic);
                     %                 Jinv=(siJ(:,indok)'*siJ(:,indok))\siJ(:,indok)';
                     %                 MIM=inv(Jinv*cmm*Jinv');
