@@ -1,22 +1,23 @@
-function D = A_times_B_kronecker_C(A,B,C)
-%function D = A_times_B_kronecker_C(A,B,C)
+function [err, D] = A_times_B_kronecker_C(A,B,C,fake)
+%function [err, D] = A_times_B_kronecker_C(A,B,C)
 % Computes A * kron(B,C). 
 %
 % INPUTS
-%   A  [double] mA*nA matrix.
-%   B  [double] mB*nB matrix.
-%   C  [double] mC*nC matrix.
-%  
+%   A   [double] mA*nA matrix.
+%   B   [double] mB*nB matrix.
+%   C   [double] mC*nC matrix.
+%
 % OUTPUTS
-%   D  [double] mA*(nC*nB) or mA*(nB*nB) matrix.
-%  
+%   err [double] scalar: 1 indicates failure, 0 indicates success
+%   D   [double] mA*(nC*nB) or mA*(nB*nB) matrix.
+%
 % ALGORITHM
 %   none.    
 %
 % SPECIAL REQUIREMENTS
 %   none.
 
-% Copyright (C) 1996-2008 Dynare Team
+% Copyright (C) 1996-2010 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -34,16 +35,15 @@ function D = A_times_B_kronecker_C(A,B,C)
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
 % Chek number of inputs and outputs.
-if nargin>3 | nargin<2
-    error('Two or Three input arguments required!')
-end
-if nargout>1
-    error('Too many output arguments!')
+if nargin>4 || nargin<3 || nargout~=2
+    error('A_times_B_kronecker_C takes 3 or 4 input arguments and provides exactly 2 output arguments.')
 end
+
+
 % Get & check dimensions. Initialization of the output matrix.
 [mA,nA] = size(A);
 [mB,nB] = size(B);
-if nargin == 3
+if nargin == 4
     [mC,nC] = size(C);
     if mB*mC ~= nA
         error('Input dimension error!')
@@ -59,7 +59,7 @@ else
 end
 % Computational part.
 if loop
-    if nargin == 3
+    if nargin == 4
         k1 = 1; 
         for i1=1:nB
             for i2=1:nC
@@ -77,9 +77,10 @@ if loop
         end
     end
 else
-    if nargin == 3
+    if nargin == 4
         D = A * kron(B,C);
     else
         D = A * kron(B,B);
     end
-end
\ No newline at end of file
+end
+err = 0;
\ No newline at end of file
