@@ -1,6 +1,6 @@
 function osr1(i_params,i_var,weights)
 
-% Copyright (C) 2005-2010 Dynare Team
+% Copyright (C) 2005-2011 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -51,7 +51,8 @@ if exist([M_.fname '_steadystate'])
             ys = add_auxiliary_variables_to_steadystate(ys,M_.aux_vars,...
                                                         M_.fname,...
                                                         oo_.exo_steady_state,...
-                                                        oo_.exo_det_steady_state,M_.params);
+                                                        oo_.exo_det_steady_state,M_.params,...
+                                                        options_.bytecode);
         else
             error([M_.fname '_steadystate.m doesn''t match the model']);
         end
@@ -61,7 +62,7 @@ else
     % testing if ys isn't a steady state or if we aren't computing Ramsey policy
     fh = str2func([M_.fname '_static']);
     if max(abs(feval(fh,oo_.steady_state,[oo_.exo_steady_state; oo_.exo_det_steady_state], M_.params))) ...
-            > options_.dynatol & options_.ramsey_policy == 0
+            > options_.dynatol && options_.ramsey_policy == 0
         if options_.linear == 0
             % nonlinear models
             [dr.ys,check1] = dynare_solve(fh,dr.ys,options_.jacobian_flag,...
@@ -95,8 +96,8 @@ crit = 1e-7;
 nit = 1000;
 verbose = 2;
 
-[f,p]=csminwel('osr_obj',t0,H0,[],crit,nit,options_.gradient_method,i_params,...
-               inv_order_var(i_var),weights(i_var,i_var));
+[f,p]=csminwel1('osr_obj',t0,H0,[],crit,nit,options_.gradient_method,options_.gradient_epsilon,i_params,...
+                inv_order_var(i_var),weights(i_var,i_var));
 
 %  options = optimset('fminunc');
 %  options = optimset('display','iter');
