@@ -33,8 +33,9 @@ if ~noprint
         error(['The model doesn''t determine the current variables' ...
                ' uniquely'])
       case 2
-        error(['MJDGGES returns the following error code: ' ...
-               int2str(info(2))])
+        error(['The generalized Schur (QZ) decomposition failed. ' ...
+               'For more information, see the documentation for Lapack function dgges: info=' ...
+               int2str(info(2)) ', n=' int2str(info(3))])
       case 3
         error(['Blanchard Kahn conditions are not satisfied: no stable' ...
                ' equilibrium'])
@@ -67,7 +68,7 @@ if ~noprint
       case 43
         error('Covariance matrix of shocks is not positive definite')
       case 44 %DsgeLikelihood_hh / DsgeLikelihood
-        error('');
+        error('The covariance matrix of the measurement errors is not positive definite.');
       case 51
         error('You are estimating a DSGE-VAR model, but the value of the dsge prior weight is too low!')
       case 52 %DsgeVarLikelihood
