@@ -83,12 +83,12 @@ if strcmpi(type,'posterior')
         B = min(1200, round(0.25*NumberOfDraws));
     end
 elseif strcmpi(type,'gsa')
-    RootDirectoryName = CheckPath('GSA');
+    RootDirectoryName = CheckPath('gsa');
     if options_.opt_gsa.pprior
-        DirectoryName = CheckPath(['GSA',filesep,'prior']);
+        DirectoryName = CheckPath(['gsa',filesep,'prior']);
         load([ RootDirectoryName filesep  M_.fname '_prior.mat'],'lpmat0','lpmat','istable')
     else
-        DirectoryName = CheckPath(['GSA',filesep,'mc']);
+        DirectoryName = CheckPath(['gsa',filesep,'mc']);
         load([ RootDirectoryName filesep  M_.fname '_mc.mat'],'lpmat0','lpmat','istable')
     end
     x=[lpmat0(istable,:) lpmat(istable,:)];
@@ -220,21 +220,28 @@ if isnumeric(options_.parallel),
     % Parallel execution!
 else
     [nCPU, totCPU, nBlockPerCPU] = distributeJobs(options_.parallel, 1, B);
+    ifil=zeros(7,totCPU);
     for j=1:totCPU-1,
-        nfiles = ceil(nBlockPerCPU(j)/MAX_nsmoo);
-        ifil(1,j+1) =ifil(1,j)+nfiles;
-        nfiles = ceil(nBlockPerCPU(j)/MAX_ninno);
-        ifil(2,j+1) =ifil(2,j)+nfiles;
-        nfiles = ceil(nBlockPerCPU(j)/MAX_nerro);
-        ifil(3,j+1) =ifil(3,j)+nfiles;
-        nfiles = ceil(nBlockPerCPU(j)/MAX_naK);
-        ifil(4,j+1) =ifil(4,j)+nfiles;
+        if run_smoother
+            nfiles = ceil(nBlockPerCPU(j)/MAX_nsmoo);
+            ifil(1,j+1) =ifil(1,j)+nfiles;
+            nfiles = ceil(nBlockPerCPU(j)/MAX_ninno);
+            ifil(2,j+1) =ifil(2,j)+nfiles;
+            nfiles = ceil(nBlockPerCPU(j)/MAX_nerro);
+            ifil(3,j+1) =ifil(3,j)+nfiles;
+        end
+        if naK
+            nfiles = ceil(nBlockPerCPU(j)/MAX_naK);
+            ifil(4,j+1) =ifil(4,j)+nfiles;
+        end
         nfiles = ceil(nBlockPerCPU(j)/MAX_nruns);
         ifil(5,j+1) =ifil(5,j)+nfiles;
-        nfiles = ceil(nBlockPerCPU(j)/MAX_nforc1);
-        ifil(6,j+1) =ifil(6,j)+nfiles;
-        nfiles = ceil(nBlockPerCPU(j)/MAX_nforc2);
-        ifil(7,j+1) =ifil(7,j)+nfiles;
+        if horizon
+            nfiles = ceil(nBlockPerCPU(j)/MAX_nforc1);
+            ifil(6,j+1) =ifil(6,j)+nfiles;
+            nfiles = ceil(nBlockPerCPU(j)/MAX_nforc2);
+            ifil(7,j+1) =ifil(7,j)+nfiles;
+        end
         %       nfiles = ceil(nBlockPerCPU(j)/MAX_momentsno);
         %       ifil(8,j+1) =ifil(8,j)+nfiles;
     end
