@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2011 Dynare Team
+ * Copyright (C) 2006-2012 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -168,7 +168,7 @@ ModFile::checkPass()
           exit(EXIT_FAILURE);
         }
       else
-        cout << "WARNING: When estimating a DSGE-Var, declaring dsge_prior_weight as a parameter is deprecated. "
+        cerr << "WARNING: When estimating a DSGE-Var, declaring dsge_prior_weight as a parameter is deprecated. "
              <<  "The preferred method is to do this via the dsge_var option in the estimation statement." << endl;
 
       if (mod_file_struct.dsge_var_estimated || !mod_file_struct.dsge_var_calibrated.empty())
@@ -339,7 +339,7 @@ ModFile::computingPass(bool no_tmp_terms)
             }
         }
       else
-        dynamic_model.computingPass(true, true, false, false, global_eval_context, no_tmp_terms, false, false, byte_code);
+        dynamic_model.computingPass(true, true, false, false, global_eval_context, no_tmp_terms, block, use_dll, byte_code);
     }
 
   for (vector<Statement *>::iterator it = statements.begin();
@@ -526,10 +526,7 @@ ModFile::writeOutputFiles(const string &basename, bool clear_all, bool console,
 
   if (dynamic_model.equation_number() > 0)
     {
-      if (dynamic_model_needed)
-        dynamic_model.writeOutput(mOutputFile, basename, block, byte_code, use_dll, mod_file_struct.order_option);
-      else
-        dynamic_model.writeOutput(mOutputFile, basename, false, false, false, mod_file_struct.order_option);
+      dynamic_model.writeOutput(mOutputFile, basename, block, byte_code, use_dll, mod_file_struct.order_option);
       if (!no_static)
         static_model.writeOutput(mOutputFile, block);
     }
@@ -573,16 +570,8 @@ ModFile::writeOutputFiles(const string &basename, bool clear_all, bool console,
       if (!no_static)
         static_model.writeStaticFile(basename, block, byte_code);
 
-      if (dynamic_model_needed)
-        {
-          dynamic_model.writeDynamicFile(basename, block, byte_code, use_dll, mod_file_struct.order_option);
-          dynamic_model.writeParamsDerivativesFile(basename);
-        }
-      else
-        {
-          dynamic_model.writeDynamicFile(basename, false, false, false, mod_file_struct.order_option);
-          dynamic_model.writeParamsDerivativesFile(basename);
-        }
+        dynamic_model.writeDynamicFile(basename, block, byte_code, use_dll, mod_file_struct.order_option);
+        dynamic_model.writeParamsDerivativesFile(basename);
     }
 
   // Create steady state file
