@@ -1354,6 +1354,15 @@ StaticModel::writeOutput(ostream &output, bool block) const
 
       output << "];" << endl;
     }
+  output << "M_.blocksEQU = cell(" << nb_blocks << ", 1);" << endl;
+  for (int b = 0; b < (int) nb_blocks; b++)
+    {
+      unsigned int block_size = getBlockSize(b);
+      output << "M_.blocksEQU{" << b+1 << "} = [ ";
+      for (int i = 0; i < (int) block_size; i++)
+         output << getBlockEquationID(b, i)+1 << "; ";
+      output << "];" << endl;
+    }
 }
 
 SymbolType
